# coding=utf-8
from __future__ import unicode_literals
from .. import Provider as PersonProvider


class Provider(PersonProvider):
    formats = ['{{first_name}} {{last_name}}', ]

    first_names_male = [
        "Franc", "Janez", "Anton", "Ivan", "Jožef", "Andrej", "Marko",
        "Marjan", "Peter", "Milan", "Stanislav", "Matej", "Tomaž", "Branko",
        "Bojan", "Robert", "Boštjan", "Matjaž", "Gregor", "Luka", "Martin",
        "Rok", "Boris", "Dušan", "Igor", "Miha", "Dejan", "David", "Uroš",
        "Simon", "Jure", "Blaž", "Štefan", "Jan", "Drago", "Darko", "Klemen",
        "Nejc", "Žiga", "Jernej", "Miran", "Aleksander", "Roman", "Vladimir",
        "Matic", "Tadej", "Srečko", "Slavko", "Mirko", "Janko", "Žan",
        "Miroslav", "Borut", "Alojzij", "Damjan", "Stanko", "Aljaž", "Anže",
        "Danijel", "Mihael", "Matija", "Jaka", "Marijan", "Rudolf", "Alen",
        "Jakob", "Viktor", "Domen", "Sašo", "Iztok", "Goran", "Tilen",
        "Pavel", "Zvonko", "Edvard", "Zdravko", "Danilo", "Matevž", "Rajko",
        "Ludvik", "Zlatko", "Frančišek", "Bogdan", "Gorazd", "Samo", "Leon",
        "Dragan", "Emil", "Josip", "Nik", "Ciril", "Sandi", "Benjamin", "Vid",
        "Albin", "Franci", "Sebastjan", "Silvo", "Leopold", "Kristjan", "Tim",
        "Filip", "Damijan", "Erik", "Viljem", "Vincenc", "Željko", "Damir",
        "Aljoša", "Karel", "Daniel", "Dominik", "Miloš", "Stojan",
        "Franjo", "Valentin", "Davorin", "Maks", "Timotej", "Ladislav", "Niko",
        "Mark", "Nikola", "Bogomir", "Saša", "Vlado", "Karl", "Zdenko",
        "Grega", "Stjepan", "Davor", "Kristijan", "Ernest", "Maksimiljan",
        "Avgust", "Sebastijan", "Aleksandar", "Lovro", "Ivo", "Rado", "Tine",
        "Adolf", "Gal", "Valter", "Elvis", "Jasmin", "Ervin", "Jani", "Izidor",
        "Nenad", "Anej", "Petar", "Maj", "Metod", "Albert", "Bruno", "Radovan",
        "Nikolaj", "Feliks", "Karol", "Bernard", "Joško", "Rafael", "Edin",
        "Aleks", "Cvetko", "Rudi", "Miro", "Hasan", "Slobodan", "Mirsad",
    ]

    first_names_female = [
        "Marija", "Ana", "Irena", "Maja", "Mojca", "Jožefa", "Mateja",
        "Nataša", "Jožica", "Barbara", "Ivana", "Andreja", "Nina", "Petra",
        "Katja", "Sonja", "Milena", "Katarina", "Tatjana", "Anja", "Alenka",
        "Tanja", "Martina", "Vesna", "Tina", "Angela", "Urška", "Antonija",
        "Anica", "Kristina", "Dragica", "Nada", "Olga", "Špela", "Darja",
        "Marjeta", "Tjaša", "Eva", "Ljudmila", "Simona", "Vida", "Sara",
        "Zdenka", "Alojzija", "Lidija", "Suzana", "Marta", "Nika", "Sabina",
        "Silva", "Veronika", "Štefanija", "Stanislava", "Darinka", "Karmen",
        "Neža", "Brigita", "Anita", "Aleksandra", "Pavla", "Cvetka", "Metka",
        "Nevenka", "Monika", "Rozalija", "Natalija", "Slavica", "Marjana",
        "Branka", "Jasmina", "Vera", "Ema", "Saša", "Maša", "Lara", "Lucija",
        "Tamara", "Bernarda", "Danijela", "Klavdija", "Erika", "Romana",
        "Mira", "Jasna", "Klara", "Kaja", "Jelka", "Polona", "Julijana",
        "Valerija", "Sandra", "Matilda", "Tadeja", "Valentina", "Mihaela",
        "Amalija", "Albina", "Breda", "Karolina", "Sanja", "Teja", "Ines",
        "Zofija", "Ksenija", "Laura", "Cecilija", "Patricija", "Magdalena",
        "Manca", "Viktorija", "Maruša", "Vanja", "Vlasta", "Justina", "Nuša",
        "Emilija", "Melita", "Ljubica", "Lana", "Marica", "Gordana", "Marinka",
        "Polonca", "Nadja", "Milka", "Živa", "Urša", "Damjana", "Hana",
        "Tea", "Marijana", "Julija", "Ajda", "Nastja", "Milica", "Alja",
        "Štefka", "Slavka", "Jerneja", "Nives", "Dušanka", "Andrejka",
        "Irma", "Pia", "Jelena", "Marjanca", "Miroslava", "Lilijana", "Stanka",
        "Mirjam", "Neja", "Jolanda", "Zora", "Zvonka", "Hermina", "Rebeka",
        "Hedvika", "Blanka", "Larisa", "Erna", "Anka", "Roza", "Liljana",
        "Magda", "Daniela", "Jerica", "Taja", "Iris", "Adrijana", "Jadranka",
    ]

    first_names = first_names_female + first_names_male
    last_names = [
        "Novak", "Horvat", "Krajnc", "Kovačič", "Zupančič", "Kovač",
        "Potočnik", "Mlakar", "Vidmar", "Kos", "Golob", "Turk", "Božič",
        "Zupan", "Korošec", "Bizjak", "Hribar", "Kotnik", "Rozman",
        "Petek", "petek", "Kastelic", "Kolar", "Hočevar", "Žagar", "žagar",
        "Košir", "Koren", "Klemenčič", "Zajc", "Medved", "Knez", "Zupanc",
        "Pirc", "Hrovat", "Pavlič", "Kuhar", "kuhar", "Lah", "Zorko",
        "Sever", "Majcen", "Jerman", "Babič", "Tomažič", "Erjavec", "Jereb",
        "Kranjc", "Rupnik", "Perko", "Lesjak", "Breznik", "Pečnik", "Pavlin",
        "Dolenc", "Vidic", "Furlan", "Logar", "Tomšič", "Jenko", "Janežič",
        "ribič", "Žnidaršič", "Černe", "Maček", "Lešnik", "Fras",
        "Marolt", "Jelen", "Gregorič", "Blatnik", "Pintar", "Mihelič",
        "Kokalj", "Bezjak", "Leban", "Cerar", "Čeh", "čeh", "Jug",
        "Vidovič", "Rus", "Kobal", "Primožič", "Kocjančič", "Dolinar",
        "Lazar", "Kolenc", "Nemec", "Kolarič", "Lavrič", "Kodrič", "Kosi",
        "Mrak", "Debeljak", "Tavčar", "Žižek", "Krivec", "Zver",
        "Likar", "Žibert", "Jarc", "Vodopivec", "Kramberger", "Miklavčič",
        "Skok", "Toplak", "Petrovič", "Hribernik", "Leskovar", "Stopar",
        "Simonič", "Blažič", "Eržen", "Sitar", "Gorenc", "Železnik",
        "Šinkovec", "Jamnik", "Javornik", "Bukovec", "Hozjan", "Ramšak",
        "Filipič", "Kočevar", "Demšar", "Volk", "volk", "Gomboc",
        "Čuk", "Ilić", "Kokol", "Bregar", "Sušnik", "Pintarič", "Gorjup",
        "Jovanović", "Mavrič", "Kramar", "Lebar", "Rutar", "Koželj",
        "Popović", "Rajh", "Hodžić", "Rožman", "Resnik", "Šmid", "Kumer",
        "Godec", "Bergant", "Pogačnik", "Zemljič", "Hafner", "Tratnik",
        "Rožič", "Cvetko", "Ambrožič", "Bevc", "Mlinarič", "Mlinar",
        "Jerič", "Kalan", "Markovič", "Šuštar", "Bajc", "Kaučič",
        "Dolinšek", "Zalokar", "Pirnat", "Zorman", "Zakrajšek", "Štrukelj",
    ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals
from .. import Provider as PersonProvider


class Provider(PersonProvider):
    formats_female = (
        '{{last_name}} {{first_name_female}}',
    )

    formats_male = (
        '{{last_name}} {{first_name_male}}',
    )

    formats = formats_male + formats_female

    first_names_female = (
        '明美',
        'あすか',
        '香織',
        '加奈',
        'くみ子',
        'さゆり',
        '知実',
        '千代',
        '直子',
        '七夏',
        '花子',
        '春香',
        '真綾',
        '舞',
        '美加子',
        '幹',
        '桃子',
        '結衣',
        '裕美子',
        '陽子',
        '里佳',
    )

    first_names_male = (
        '晃',
        '篤司',
        '治',
        '和也',
        '京助',
        '健一',
        '修平',
        '翔太',
        '淳',
        '聡太郎',
        '太一',
        '太郎',
        '拓真',
        '翼',
        '智也',
        '直樹',
        '直人',
        '英樹',
        '浩',
        '学',
        '充',
        '稔',
        '裕樹',
        '裕太',
        '康弘',
        '陽一',
        '洋介',
        '亮介',
        '涼平',
        '零',
    )

    first_names = first_names_male + first_names_female

    last_names = (
        '青田', '青山', '石田', '井高', '伊藤', '井上', '宇野', '江古田', '大垣',
        '加藤', '加納', '喜嶋', '木村', '桐山', '工藤', '小泉', '小林', '近藤',
        '斉藤', '坂本', '佐々木', '佐藤', '笹田', '鈴木', '杉山',
        '高橋', '田中', '田辺', '津田',
        '中島', '中村', '渚', '中津川', '西之園', '野村',
        '原田', '浜田', '廣川', '藤本',
        '松本', '三宅', '宮沢', '村山',
        '山岸', '山口', '山田', '山本', '吉田', '吉本',
        '若松', '渡辺',
    )

    kana_formats = (
        '{{last_kana_name}} {{first_kana_name_female}}',
        '{{last_kana_name}} {{first_kana_name_male}}',
    )

    first_kana_names_female = (
        'アキラ', 'アケミ', 'アスカ',
        'カオリ', 'カナ', 'クミコ',
        'サユリ',
        'チヨ', 'ツバサ', 'トモミ',
        'ナオコ', 'ナナカ',
        'ハナコ', 'ハルカ',
        'マアヤ', 'マイ', 'ミキ', 'モモコ',
        'ユイ', 'ヨウコ', 'ユミコ',
        'レイ', 'リカ',
    )

    first_kana_names_male = (
        'アキラ', 'アツシ', 'オサム',
        'キョウスケ', 'ケンイチ',
        'ジュン', 'ソウタロウ',
        'タイチ', 'タクマ', 'タロウ', 'ツバサ', 'トモヤ',
        'ナオキ', 'ナオト',
        'ヒデキ', 'ヒロシ',
        'マナブ', 'ミツル', 'ミノル', 'ヒロキ',
        'ユウタ', 'ヤスヒロ', 'ヨウイチ', 'ヨウスケ',
        'リョウスケ', 'リョウヘイ',
    )

    first_kana_names = first_kana_names_male + first_kana_names_female

    last_kana_names = (
        'アオタ', 'アオヤマ', 'イシダ', 'イダカ', 'イトウ', 'ウノ', 'エコダ', 'オオガキ',
        'カノウ', 'カノウ', 'キジマ', 'キムラ', 'キリヤマ', 'クドウ', 'コイズミ', 'コバヤシ', 'コンドウ',
        'サイトウ', 'サカモト', 'ササキ', 'サトウ', 'ササダ', 'スズキ', 'スギヤマ',
        'タカハシ', 'タナカ', 'タナベ', 'ツダ', 'ツチヤ',
        'ナカジマ', 'ナカムラ', 'ナギサ', 'ナカツガワ', 'ニシノソノ', 'ノムラ',
        'ハラダ', 'ハマダ', 'ヒロカワ', 'フジモト',
        'マツモト', 'ミヤケ', 'ミヤザワ', 'ムラヤマ',
        'ヤマギシ', 'ヤマグチ', 'ヤマダ', 'ヤマモト', 'ヨシダ', 'ヨシモト',
        'ワカマツ', 'ワタナベ',
    )

    romanized_formats = (
        '{{first_romanized_name_female}} {{last_romanized_name}}',
        '{{first_romanized_name_male}} {{last_romanized_name}}',
    )

    first_romanized_names_female = (
        'Akira', 'Akemi', 'Asuka',
        'Kaori', 'Kana', 'Kumiko',
        'Sayuri',
        'Chiyo', 'Tsubasa', 'Tomomi',
        'Naoko', 'Nanaka',
        'Hanako', 'Haruka',
        'Maaya', 'Mai', 'Miki', 'Momoko',
        'Yui', 'Yoko', 'Yumiko',
        'Rei', 'Rika',
    )

    first_romanized_names_male = (
        'Akira', 'Atsushi', 'Osamu',
        'Kyosuke', 'Kenichi',
        'Jun', 'Sotaro',
        'Taichi', 'Takuma', 'Taro', 'Tsubasa', 'Tomoya',
        'Naoki', 'Naoto'
        'Hideki', 'Hiroshi',
        'Manabu', 'Mituru', 'Minoru', 'Hiroki',
        'Yuta', 'Yasuhiro', 'Yoichi', 'Yosuke',
        'Ryosuke', 'Ryohei',
    )

    first_romanized_names = first_romanized_names_male + first_romanized_names_female

    last_romanized_names = (
        'Aota',
        'Aoyama',
        'Ishida',
        'Idaka',
        'Ito',
        'Uno',
        'Ekoda',
        'Ogaki',
        'Kato',
        'Kano',
        'Kijima',
        'Kimura',
        'Kiriyama',
        'Kudo',
        'Koizumi',
        'Kobayashi',
        'Kondo',
        'Saito',
        'Sakamoto',
        'Sasaki',
        'Sato',
        'Sasada',
        'Suzuki',
        'Sugiyama',
        'Takahashi',
        'Tanaka',
        'Tanabe',
        'Tsuda',
        'Tsuchiya',
        'Nakajima',
        'Nakamura',
        'Nagisa',
        'Nakatsugawa',
        'Nishinosono',
        'Nomura',
        'Harada',
        'Hamada',
        'Hirokawa',
        'Fujimoto',
        'Matsumoto',
        'Miyake',
        'Miyagawa',
        'Murayama',
        'Yamagishi',
        'Yamaguchi',
        'Yamada',
        'Yamamoto',
        'Yoshida',
        'Yoshimoto',
        'Wakamatsu',
        'Watanabe',
    )

    def kana_name(self):
        '''
        @example 'アオタ アキラ'
        '''
        pattern = self.random_element(self.kana_formats)
        return self.generator.parse(pattern)

    def first_kana_name(self):
        '''
        @example 'アキラ'
        '''
        return self.random_element(self.first_kana_names)

    def first_kana_name_female(self):
        return self.random_element(self.first_kana_names_female)

    def first_kana_name_male(self):
        return self.random_element(self.first_kana_names_male)

    def last_kana_name(self):
        '''
        @example 'アオタ'
        '''
        return self.random_element(self.last_kana_names)

    def romanized_name(self):
        '''
        @example 'Akira Aota'
        '''
        pattern = self.random_element(self.romanized_formats)
        return self.generator.parse(pattern)

    def first_romanized_name(self):
        '''
        @example 'Akira'
        '''
        return self.random_element(self.first_romanized_names)

    def first_romanized_name_female(self):
        return self.random_element(self.first_romanized_names_female)

    def first_romanized_name_male(self):
        return self.random_element(self.first_romanized_names_male)

    def last_romanized_name(self):
        '''
        @example 'Aota'
        '''
        return self.random_element(self.last_romanized_names)



from __future__ import unicode_literals
from .. import Provider as PhoneNumberProvider


class Provider(PhoneNumberProvider):
    formats = (
        '+371 ########',
        '+(371) ########',
        '+371########'
    )



# -*- coding: utf-8 -*-
from __future__ import unicode_literals
from .. import Provider as PhoneNumberProvider


class Provider(PhoneNumberProvider):
    formats = (
        '070-####-####',
        '080-####-####',
        '090-####-####',
        '##-####-####',
    )



# coding=utf-8
from __future__ import unicode_literals

from text_unidecode import unidecode

from .. import BaseProvider

from ipaddress import ip_address, ip_network, IPV4LENGTH, IPV6LENGTH

# from faker.generator import random
# from faker.providers.lorem.la import Provider as Lorem
from faker.utils.decorators import lowercase, slugify, slugify_unicode


localized = True


IPV4_PUBLIC_NETS = {
    'a': ip_network('0.0.0.0/1'),
    'b': ip_network('128.0.0.0/2'),
    'c': ip_network('192.0.0.0/3')
}
IPV4_PRIVATE_NET_BLOCKS = {
    'a': (
        ip_network('0.0.0.0/8'),
        ip_network('10.0.0.0/8'),
        ip_network('127.0.0.0/8'),
    ),
    'b': (
        ip_network('169.254.0.0/16'),
        ip_network('172.16.0.0/12')
    ),
    'c': (
        ip_network('192.0.0.0/29'),
        ip_network('192.0.0.170/31'),
        ip_network('192.0.2.0/24'),
        ip_network('192.168.0.0/16'),
        ip_network('198.18.0.0/15'),
        ip_network('198.51.100.0/24'),
        ip_network('203.0.113.0/24')
    ),
}
IPV4_NET_CLASSES = {
    'a': (167772160, 184549375, 24),
    'b': (2886729728, 2887778303, 20),
    'c': (3232235520, 3232301055, 16)
}


class Provider(BaseProvider):
    safe_email_tlds = ('org', 'com', 'net')
    free_email_domains = ('gmail.com', 'yahoo.com', 'hotmail.com')
    tlds = (
        'com', 'com', 'com', 'com', 'com', 'com', 'biz', 'info', 'net', 'org'
    )

    uri_pages = (
        'index', 'home', 'search', 'main', 'post', 'homepage', 'category',
        'register', 'login', 'faq', 'about', 'terms', 'privacy', 'author'
    )
    uri_paths = (
        'app', 'main', 'wp-content', 'search', 'category', 'tag', 'categories',
        'tags', 'blog', 'posts', 'list', 'explore'
    )
    uri_extensions = (
        '.html', '.html', '.html', '.htm', '.htm', '.php', '.php', '.jsp',
        '.asp'
    )

    user_name_formats = (
        '{{last_name}}.{{first_name}}',
        '{{first_name}}.{{last_name}}',
        '{{first_name}}##',
        '?{{last_name}}',
    )
    email_formats = (
        '{{user_name}}@{{domain_name}}',
        '{{user_name}}@{{free_email_domain}}',
    )
    url_formats = (
        'www.{{domain_name}}/',
        '{{domain_name}}/',
    )
    uri_formats = (
        '{{url}}',
        '{{url}}{{uri_page}}/',
        '{{url}}{{uri_page}}{{uri_extension}}',
        '{{url}}{{uri_path}}/{{uri_page}}/',
        '{{url}}{{uri_path}}/{{uri_page}}{{uri_extension}}',
    )
    image_placeholder_services = (
        'https://placeholdit.imgix.net/~text'
        '?txtsize=55&txt={width}x{height}&w={width}&h={height}',
        'https://www.lorempixel.com/{width}/{height}',
        'https://dummyimage.com/{width}x{height}',
    )

    replacements = tuple()

    def _to_ascii(self, string):
        for search, replace in self.replacements:
            string = string.replace(search, replace)

        string = unidecode(string)
        return string

    @lowercase
    def email(self, domain=None):
        if domain:
            email = '{0}@{1}'.format(self.user_name(), domain)
        else:
            pattern = self.random_element(self.email_formats)
            email = "".join(self.generator.parse(pattern).split(" "))
        return email

    @lowercase
    def safe_email(self):
        return '{}@example.{}'.format(
            self.user_name(), self.random_element(self.safe_email_tlds)
        )

    @lowercase
    def free_email(self):
        return self.user_name() + '@' + self.free_email_domain()

    @lowercase
    def company_email(self):
        return self.user_name() + '@' + self.domain_name()

    @lowercase
    def free_email_domain(self):
        return self.random_element(self.free_email_domains)

    @lowercase
    def ascii_email(self):
        pattern = self.random_element(self.email_formats)
        return self._to_ascii(
            "".join(self.generator.parse(pattern).split(" "))
        )

    @lowercase
    def ascii_safe_email(self):
        return self._to_ascii(
            self.user_name() +
            '@example.' +
            self.random_element(self.safe_email_tlds)
        )

    @lowercase
    def ascii_free_email(self):
        return self._to_ascii(
            self.user_name() + '@' + self.free_email_domain()
        )

    @lowercase
    def ascii_company_email(self):
        return self._to_ascii(
            self.user_name() + '@' + self.domain_name()
        )

    @slugify_unicode
    def user_name(self):
        pattern = self.random_element(self.user_name_formats)
        username = self._to_ascii(
            self.bothify(self.generator.parse(pattern)).lower()
        )
        return username

    @lowercase
    def domain_name(self, levels=1):
        """
        Produce an Internet domain name with the specified number of
        subdomain levels.

        >>> domain_name()
        nichols-phillips.com
        >>> domain_name(2)
        williamson-hopkins.jackson.com
        """
        if levels < 1:
            raise ValueError("levels must be greater than or equal to 1")
        if levels == 1:
            return self.domain_word() + '.' + self.tld()
        else:
            return self.domain_word() + '.' + self.domain_name(levels - 1)

    @lowercase
    @slugify_unicode
    def domain_word(self,):
        company = self.generator.format('company')
        company_elements = company.split(' ')
        company = self._to_ascii(company_elements.pop(0))
        return company

    def tld(self):
        return self.random_element(self.tlds)

    def url(self, schemes=None):
        """
        :param schemes: a list of strings to use as schemes, one will chosen randomly.
        If None, it will generate http and https urls.
        Passing an empty list will result in schemeless url generation like "://domain.com".

        :returns: a random url string.
        """
        if schemes is None:
            schemes = ['http', 'https']

        pattern = '{}://{}'.format(
            self.random_element(schemes) if schemes else "",
            self.random_element(self.url_formats)
        )

        return self.generator.parse(pattern)

    def ipv4(self, network=False, address_class=None, private=None):
        """
        Produce a random IPv4 address or network with a valid CIDR.

        :param network: Network address
        :param address_class: IPv4 address class (a, b, or c)
        :param private: Public or private
        :returns: IPv4
        """
        if private is True:
            return self.ipv4_private(address_class=address_class,
                                     network=network)
        elif private is False:
            return self.ipv4_public(address_class=address_class,
                                    network=network)
        if address_class is None:
            ip_range = (0, (2 ** IPV4LENGTH) - 1)
        else:
            net = IPV4_PUBLIC_NETS[address_class]
            ip_range = (net._ip[0], net.ip[-1])
        address = str(ip_address(self.generator.random.randint(*ip_range)))
        if network:
            address += '/' + str(self.generator.random.randint(0, IPV4LENGTH))
            address = str(ip_network(address, strict=False))
        return address

    def ipv4_network_class(self):
        """
        Returns a IPv4 network class 'a', 'b' or 'c'.

        :returns: IPv4 network class
        """
        return self.random_element('abc')

    def ipv4_private(self, network=False, address_class=None):
        """
        Returns a private IPv4.

        :param network: Network address
        :param address_class: IPv4 address class (a, b, or c)
        :returns: Private IPv4
        """
        address_class = address_class or self.ipv4_network_class()
        min_, max_, netmask = IPV4_NET_CLASSES[address_class]
        address = str(ip_address(
            self.generator.random.randint(min_, max_)))
        if network:
            address += '/' + str(self.generator.random.randint(netmask, 31))
            address = str(ip_network(address, strict=False))
        return address

    def ipv4_public(self, network=False, address_class=None):
        """
        Returns a public IPv4 excluding private blocks.

        :param network: Network address
        :param address_class: IPv4 address class (a, b, or c)
        :returns: Public IPv4
        """
        address_class = address_class or self.ipv4_network_class()
        public_net = IPV4_PUBLIC_NETS[address_class]
        private_blocks = IPV4_PRIVATE_NET_BLOCKS[address_class]
        # Make valid IP ranges, created from private block exclusion
        net_ranges = []
        ## Starts at end of 1st block if it's 1st of class
        if public_net[0] != private_blocks[0][0]:
            net_ranges = [(public_net[0]._ip, private_blocks[0][0]._ip-1)]
        ## Loop on private blocks and guess available ranges
        for i, block in enumerate(private_blocks):
            if i+1 == len(private_blocks):
                break
            net_range = (block[-1]._ip+1, private_blocks[i+1][0]._ip-1)
            net_ranges.append(net_range)
        ## Add last range
        net_ranges.append((private_blocks[-1][-1]._ip-1, public_net[-1]._ip-1))
        net_ranges = [(i, j) for i, j in net_ranges if (j-i) > 0]
        # Choose a range
        min_, max_ = self.generator.random.choice(net_ranges)
        address = str(ip_address(
            self.generator.random.randint(min_, max_)))
        # Add network mask
        if network:
            net_masks = {'a': 8, 'b': 16, 'c': 24}
            min_net_mask = net_masks[address_class]
            address += '/' + str(self.generator.random.randint(min_net_mask, 31))
            address = str(ip_network(address, strict=False))
        return address

    def ipv6(self, network=False):
        """Produce a random IPv6 address or network with a valid CIDR"""
        address = str(ip_address(self.generator.random.randint(
            2 ** IPV4LENGTH, (2 ** IPV6LENGTH) - 1)))
        if network:
            address += '/' + str(self.generator.random.randint(0, IPV6LENGTH))
            address = str(ip_network(address, strict=False))
        return address

    def mac_address(self):
        mac = [self.generator.random.randint(0x00, 0xff) for _ in range(0, 6)]
        return ":".join(map(lambda x: "%02x" % x, mac))

    def uri_page(self):
        return self.random_element(self.uri_pages)

    def uri_path(self, deep=None):
        deep = deep if deep else self.generator.random.randint(1, 3)
        return "/".join(
            [self.random_element(self.uri_paths) for _ in range(0, deep)]
        )

    def uri_extension(self):
        return self.random_element(self.uri_extensions)

    def uri(self):
        pattern = self.random_element(self.uri_formats)
        return self.generator.parse(pattern)

    @slugify
    def slug(self, value=None):
        """Django algorithm"""
        if value is None:
            value = self.generator.text(20)
        return value

    def image_url(self, width=None, height=None):
        """
        Returns URL to placeholder image
        Example: http://placehold.it/640x480
        """
        width_ = width or self.random_int(max=1024)
        height_ = height or self.random_int(max=1024)
        placeholder_url = self.random_element(self.image_placeholder_services)
        return placeholder_url.format(width=width_, height=height_)



from __future__ import unicode_literals
from .. import Provider as PhoneNumberProvider


class Provider(PhoneNumberProvider):
    formats = (
        '+91 ##########',
        '+91 ### #######',
        '0##-########',
        '0##########',
        '0#### ######',
    )



# coding=utf-8
from __future__ import unicode_literals
from .. import Provider as CompanyProvider


class Provider(CompanyProvider):
    formats = (
        '{{last_name}} {{company_suffix}}',
        '{{last_name}} {{last_name}} {{company_suffix}}',
        '{{last_name}}',
        '{{last_name}}',
    )

    catch_phrase_formats = (
        '{{catch_phrase_noun}} {{catch_phrase_verb}} {{catch_phrase_attribute}}', )

    nouns = (
        'a segurança', 'o prazer', 'o conforto', 'a simplicidade', 'a certeza',
        'a arte', 'o poder', 'o direito', 'a possibilidade', 'a vantagem',
        'a liberdade'
    )

    verbs = (
        'de conseguir', 'de avançar', 'de evoluir', 'de mudar', 'de inovar',
        'de ganhar', 'de atingir os seus objetivos',
        'de concretizar seus projetos', 'de realizar seus sonhos'
    )

    attributes = (
        'de maneira eficaz', 'mais rapidamente', 'mais facilmente',
        'simplesmente', 'com toda a tranquilidade', 'antes de tudo',
        'naturalmente', 'sem preocupação', 'em estado puro', 'com força total',
        'direto da fonte', 'com confiança'
    )

    company_suffixes = ('S/A', 'S.A.', 'Lda.', 'e Filhos')



# coding=utf-8
from __future__ import unicode_literals

from collections import OrderedDict

from .. import Provider as ColorProvider


class Provider(ColorProvider):
    # Source: uk.wikipedia.org/wiki/Список_кольорів
    all_colors = OrderedDict((
        ('Абрикосовий', '#FBCEB1'),
        ('Аквамариновий', '#7FFFD4'),
        ('Алізариновий червоний', '#E32636'),
        ('Амарантовий', '#E52B50'),
        ('Амарантово-рожевий', '#F19CBB'),
        ('Аметистовий', '#9966CC'),
        ('Андроїдний зелений', '#A4C639'),
        ('Арсеновий', '#3B444B'),
        ('Атомний мандаріновий', '#FF9966'),
        ('Багряний', '#FF2400'),
        ('Баклажановий', '#990066'),
        ('Барвінковий', '#CCCCFF'),
        ('Бежевий', '#F5F5DC'),
        ('Берлінська лазур', '#003153'),
        ('Блаватний', '#6495ED'),
        ('Блакитний', '#AFEEEE'),
        ('Блакитний Брандейса', '#0070FF'),
        ('Блакитно-зелений', '#00DDDD'),
        ('Блакитно-фіолетовий', '#8A2BE2'),
        ('Блідий рожево-ліловий', '#996666'),
        ('Блідо-брунатний', '#987654'),
        ('Блідо-волошковий', '#ABCDEF'),
        ('Блідо-карміновий', '#AF4035'),
        ('Блідо-каштановий', '#DDADAF'),
        ('Блідо-пурпуровий', '#F984E5'),
        ('Блідо-пісочний', '#DABDAB'),
        ('Блідо-рожевий', '#FADADD'),
        ('Болотний', '#ACB78E'),
        ('Бронзовий', '#CD7F32'),
        ('Брунатний', '#964B00'),
        ('Брунато-малиновий', '#800000'),
        ('Будяковий', '#D8BFD8'),
        ('Бузковий', '#C8A2C8'),
        ('Бургундський', '#900020'),
        ('Бурий', '#755A57'),
        ('Бурштиновий', '#FFBF00'),
        ('Білий', '#FFFFFF'),
        ('Білий навахо', '#FFDEAD'),
        ('Бірюзовий', '#30D5C8'),
        ('Бістр', '#3D2B1F'),
        ('Вода пляжа Бонді', '#0095B6'),
        ('Вохра', '#CC7722'),
        ('Відбірний жовтий', '#FFBA00'),
        ('Візантійський', '#702963'),
        ('Гарбуз', '#FF7518'),
        ('Гарячо-рожевий', '#FC0FC0'),
        ('Геліотроп', '#DF73FF'),
        ('Глибокий фіолетовий', '#423189'),
        ('Глицінія', '#C9A0DC'),
        ('Грушевий', '#D1E231'),
        ('Гумігут', '#E49B0F'),
        ('Гірчичний', '#FFDB58'),
        ('Дерева', '#79443B'),
        ('Джинсовий', '#1560BD'),
        ('Діамантово-рожевий', '#FF55A3'),
        ('Жовтий', '#FFFF00'),
        ('Жовто-зелений', '#ADFF2F'),
        ('Жовто-персиковий', '#FADFAD'),
        ('Захисний синій', '#1E90FF'),
        ('Зелена весна', '#00FF7F'),
        ('Зелена мʼята', '#98FF98'),
        ('Зелена сосна', '#01796F'),
        ('Зелене море', '#2E8B57'),
        ('Зелений', '#00FF00'),
        ('Зелений армійський', '#4B5320'),
        ('Зелений мох', '#ADDFAD'),
        ('Зелений папороть', '#4F7942'),
        ('Зелений чай', '#D0F0C0'),
        ('Зелено-сірий чай', '#CADABA'),
        ('Зеленувато-блакитний', '#008080'),
        ('Золотаво-березовий', '#DAA520'),
        ('Золотий', '#FFD700'),
        ('Золотисто-каштановий', '#6D351A'),
        ('Індиго', '#4B0082'),
        ('Іржавий', '#B7410E'),
        ('Кардинал (колір)', '#C41E3A'),
        ('Карміновий', '#960018'),
        ('Каштановий', '#CD5C5C'),
        ('Кобальтовий', '#0047AB'),
        ('Колір жовтого шкільного автобуса', '#FFD800'),
        ('Колір засмаги', '#D2B48C'),
        ('Колір морської піни', '#FFF5EE'),
        ('Колір морської хвилі', '#00FFFF'),
        ('Кораловий', '#FF7F50'),
        ('Королівський синій', '#4169E1'),
        ('Кремовий', '#FFFDD0'),
        ('Кукурудзяний', '#FBEC5D'),
        ('Кіновар', '#FF4D00'),
        ('Лавандний', '#E6E6FA'),
        ('Лазуровий', '#007BA7'),
        ('Лазурово-синій', '#2A52BE'),
        ('Лайм', '#CCFF00'),
        ('Латунний', '#B5A642'),
        ('Лимонний', '#FDE910'),
        ('Лимонно-кремовий', '#FFFACD'),
        ('Лляний', '#EEDC82'),
        ('Лляний', '#FAF0E6'),
        ('Лососевий', '#FF8C69'),
        ('Ліловий', '#DB7093'),
        ('Малахітовий', '#0BDA51'),
        ('Малиновий', '#DC143C'),
        ('Мандариновий', '#FFCC00'),
        ('Мисливський', '#004225'),
        ('Морквяний', '#ED9121'),
        ('Мідний', '#B87333'),
        ('Міжнародний помаранчевий', '#FF4F00'),
        ('Нефритовий', '#00A86B'),
        ('Ніжно-блакитний', '#E0FFFF'),
        ('Ніжно-оливковий', '#6B8E23'),
        ('Ніжно-рожевий', '#FB607F'),
        ('Оливковий', '#808000'),
        ('Опівнічно-синій', '#003366'),
        ('Орхідея', '#DA70D6'),
        ('Палена сіена', '#E97451'),
        ('Палений оранжевий', '#CC5500'),
        ('Панг', '#C7FCEC'),
        ('Паросток папаї', '#FFEFD5'),
        ('Пастельно-зелений', '#77DD77'),
        ('Пастельно-рожевий', '#FFD1DC'),
        ('Персиковий', '#FFE5B4'),
        ('Перський синій', '#6600FF'),
        ('Помаранчевий', '#FFA500'),
        ('Помаранчево-персиковий', '#FFCC99'),
        ('Помаранчево-рожевий', '#FF9966'),
        ('Пурпурний', '#FF00FF'),
        ('Пурпуровий', '#660099'),
        ('Пшеничний', '#F5DEB3'),
        ('Пісочний колір', '#F4A460'),
        ('Рожевий', '#FFC0CB'),
        ('Рожевий Маунтбеттена', '#997A8D'),
        ('Рожево-лавандний', '#FFF0F5'),
        ('Рожево-ліловий', '#993366'),
        ('Салатовий', '#7FFF00'),
        ('Сангрія', '#92000A'),
        ('Сапфіровий', '#082567'),
        ('Світло-синій', '#007DFF'),
        ('Сепія', '#704214'),
        ('Сиваво-зелений', '#ACE1AF'),
        ('Сигнально-помаранчевий', '#FF9900'),
        ('Синя пил', '#003399'),
        ('Синя сталь', '#4682B4'),
        ('Сині яйця малинівки', '#00CCCC'),
        ('Синій', '#0000FF'),
        ('Синій (RYB)', '#0247FE'),
        ('Синій (пігмент)', '#333399'),
        ('Синій ВПС', '#5D8AA8'),
        ('Синій Клейна', '#3A75C4'),
        ('Сливовий', '#660066'),
        ('Смарагдовий', '#50C878'),
        ('Спаржевий', '#7BA05B'),
        ('Срібний', '#C0C0C0'),
        ('Старе золото', '#CFB53B'),
        ('Сіра спаржа', '#465945'),
        ('Сірий', '#808080'),
        ('Сірий шифер', '#708090'),
        ('Темний весняно-зелений', '#177245'),
        ('Темний жовто-брунатний', '#918151'),
        ('Темний зелений чай', '#BADBAD'),
        ('Темний пастельно-зелений', '#03C03C'),
        ('Темний хакі', '#BDB76B'),
        ('Темний індиго', '#310062'),
        ('Темно-аспідний сірий', '#2F4F4F'),
        ('Темно-брунатний', '#654321'),
        ('Темно-бірюзовий', '#116062'),
        ('Темно-зелений', '#013220'),
        ('Темно-зелений хакі', '#78866B'),
        ('Темно-золотий', '#B8860B'),
        ('Темно-карміновий', '#560319'),
        ('Темно-каштановий', '#986960'),
        ('Темно-кораловий', '#CD5B45'),
        ('Темно-лазурний', '#08457E'),
        ('Темно-лососевий', '#E9967A'),
        ('Темно-мандариновий', '#FFA812'),
        ('Темно-оливковий', '#556832'),
        ('Темно-персиковий', '#FFDAB9'),
        ('Темно-рожевий', '#E75480'),
        ('Темно-синій', '#000080'),
        ('Ультрамариновий', '#120A8F'),
        ('Умбра', '#734A12'),
        ('Умбра палена', '#8A3324'),
        ('Фуксія', '#FF00FF'),
        ('Фіолетовий', '#8B00FF'),
        ('Фіолетово-баклажановий', '#991199'),
        ('Фіолетово-червоний', '#C71585'),
        ('Хакі', '#C3B091'),
        ('Цинамоновий', '#7B3F00'),
        ('Циннвальдит', '#EBC2AF'),
        ('Ціан (колір)', '#00FFFF'),
        ('Ціано-блакитний', '#F0F8FF'),
        ('Червоний', '#FF0000'),
        ('Червоно-буро-помаранчевий', '#CD5700'),
        ('Червоновато-брунатний', '#CC8899'),
        ('Чорний', '#000000'),
        ('Шафрановий', '#F4C430'),
        ('Шкіра буйвола', '#F0DC82'),
        ('Шоколадний', '#D2691E'),
        ('Яскраво-бурштиновий', '#FF7E00'),
        ('Яскраво-бірюзовий', '#08E8DE'),
        ('Яскраво-зелений', '#66FF00'),
        ('Яскраво-зелений', '#40826D'),
        ('Яскраво-рожевий', '#FF007F'),
        ('Яскраво-фіолетовий', '#CD00CD'),
        ('Ясно-брунатний', '#CD853F'),
        ('Ясно-вишневий', '#DE3163'),
        ('Ясно-лазуровий', '#007FFF'),
        ('Ясно-лазуровий (веб)', '#F0FFFF')
    ))



# coding=utf-8
from __future__ import unicode_literals
from collections import OrderedDict

from .. import Provider as ColorProvider

localized = True


class Provider(ColorProvider):
    all_colors = OrderedDict((
        ("Noir", "#000000"),
        ("Gris mat", "#696969"),
        ("Gris", "#808080"),
        ("Gris foncé (Acier)", "#A9A9A9"),
        ("Gris argent", "#C0C0C0"),
        ("Gris clair", "#D3D3D3"),
        ("Gris gainsboro (Etain)", "#DCDCDC"),
        ("Blanc fumée", "#F5F5F5"),
        ("Blanc spectral", "#F8F8FF"),
        ("Blanc", "#FFFFFF"),
        ("Ivoire", "#FFFFF0"),
        ("Blanc floral", "#FFFAF0"),
        ("Blanc coquillage", "#FFF5EE"),
        ("Blanc lavande", "#FFF0F5"),
        ("Blanc dentelle", "#FDF5E6"),
        ("Blanc Lin", "#FAF0E6"),
        ("Rose brumeux", "#FFE4E1"),
        ("Rose", "#FFC0CB"),
        ("Rose clair", "#FFB6C1"),
        ("Rose Passion", "#FF69B4"),
        ("Rose profond", "#FF1493"),
        ("Violet pâle", "#DB7093"),
        ("Fushia (Magenta)", "#FF00FF"),
        ("Violet moyen", "#C71585"),
        ("Violet chardon", "#D8BFD8"),
        ("Prune", "#DDA0DD"),
        ("Violet", "#EE82EE"),
        ("Violet orchidée", "#DA70D6"),
        ("Violet orchidée moyen", "#BA55D3"),
        ("Violet orchidée foncé", "#9932CC"),
        (u"Violet foncé", "#9400D3"),
        ("Bleu violet", "#8A2BE2"),
        ("Indigo", "#4B0082"),
        ("Bleu ardoise moyen", "#7B68EE"),
        ("Bleu ardoise", "#6A5ACD"),
        ("Bleu ardoise foncé", "#483D8B"),
        ("Pourpre moyen", "#9370DB"),
        ("Magenta foncé", "#8B008B"),
        ("Pourpre", "#800080"),
        ("Brun rosé", "#BC8F8F"),
        ("Corail clair", "#F08080"),
        ("Corail", "#FF7F50"),
        ("Tomate", "#FF6347"),
        ("Orangé", "#FF4500"),
        ("Rouge", "#FF0000"),
        ("Rouge cramoisi", "#DC143C"),
        ("Saumon clair", "#FFA07A"),
        ("Saumon Foncé", "#E9967A"),
        ("Saumon", "#FA8072"),
        ("Rouge Indien", "#CD5C5C"),
        ("Rouge brique", "#B22222"),
        ("Brun", "#A52A2A"),
        ("Rouge foncé", "#8B0000"),
        ("Bordeaux", "#800000"),
        ("Beige", "#F5F5DC"),
        ("Beige antique", "#FAEBD7"),
        ("Beige papaye", "#FFEFD5"),
        ("Amande", "#FFEBCD"),
        ("Bisque", "#ffe4c4"),
        ("Beige pêche", "#FFDAB9"),
        ("Beige mocassin", "#FFE4B5"),
        ("Jaune blanc navaro", "#FFDEAD"),
        ("Jaune blé", "#F5DEB3"),
        ("Brun bois rustique", "#DEB887"),
        ("Brun roux", "#D2B48C"),
        ("Brun sable", "#F4A460"),
        ("Orange", "#FFA500"),
        ("Orange foncé", "#FF8C00"),
        ("Chocolat", "#D2691E"),
        ("Brun pérou", "#CD853F"),
        ("Terre de Sienne", "#A0522D"),
        ("Brun cuir", "#8B4513"),
        ("Jaune clair", "#FFFFE0"),
        ("Jaune maïs doux", "#FFF8DC"),
        ("Jaune doré clair", "#FAFAD2"),
        ("Beige citron soie", "#FFFACD"),
        ("Jaune doré pâle", "#EEE8AA"),
        ("Brun kaki", "#F0E68C"),
        ("Jaune", "#FFFF00"),
        ("Or", "#FFD700"),
        ("Jaune doré", "#DAA520"),
        ("Jaune doré foncé", "#B8860B"),
        ("Brun kaki foncé", "#BDB76B"),
        ("Jaune vert", "#9ACD32"),
        ("Kaki", "#6B8E23"),
        ("Olive", "#808000"),
        ("Vert olive foncé", "#556B2F"),
        ("Vert jaune", "#ADFF2F"),
        ("Chartreuse", "#7FFF00"),
        ("Vert prairie", "#7CFC00"),
        ("Citron vert", "#00FF00"),
        ("Citron vert foncé", "#32CD32"),
        ("Blanc menthe", "#F5FFFA"),
        ("Miellat", "#F0FFF0"),
        ("Vert pâle", "#98FB98"),
        ("Vert clair", "#90EE90"),
        ("Vert printemps", "#00FF7F"),
        ("Vert printemps moyen", "#00FA9A"),
        ("Vert forêt", "#228B22"),
        ("Vert", "#008000"),
        ("Vert foncé", "#006400"),
        ("Vert océan foncé", "#8FBC8F"),
        ("Vert océan moyen", "#3CB371"),
        ("Vert océan", "#2E8B57"),
        ("Gris ardoise clair", "#778899"),
        ("Gris ardoise", "#708090"),
        ("Gris ardoise foncé", "#2F4F4F"),
        ("Bleu alice", "#F0F8FF"),
        ("Bleu azur", "#F0FFFF"),
        ("Cyan clair", "#E0FFFF"),
        ("Azurin", "#AFEEEE"),
        ("Aigue-marine", "#7FFFD4"),
        ("Aigue-marine moyen", "#66CDAA"),
        ("Cyan", "#00FFFF"),
        ("Turquoise", "#40E0D0"),
        ("Turquoise moyen", "#48D1CC"),
        ("Turquoise foncé", "#00CED1"),
        ("Vert marin clair", "#20B2AA"),
        ("Cyan foncé", "#008B8B"),
        ("Vert sarcelle", "#008080"),
        ("Bleu pétrole", "#5F9EA0"),
        ("Bleu poudre", "#B0E0E6"),
        ("Bleu clair", "#ADD8E6"),
        ("Bleu azur clair", "#87CEFA"),
        ("Bleu azur", "#87CEEB"),
        ("Bleu azur profond", "#00BFFF"),
        ("Bleu toile", "#1E90FF"),
        ("Bleu lavande", "#E6E6FA"),
        ("Bleu acier clair", "#B0C4DE"),
        ("Bleuet", "#6495ED"),
        ("Bleu acier", "#4682B4"),
        ("Bleu royal", "#4169E1"),
        ("Bleu", "#0000FF"),
        ("Bleu moyen", "#0000CD"),
        ("Bleu foncé", "#00008B"),
        ("Bleu marin", "#000080"),
        ("Bleu de minuit", "#191970"),
    ))

    safe_colors = (
        'noir', 'bordeaux', 'vert', 'rouge',
        'violet', 'sarcelle', 'bleu', 'argent',
        'gris', 'jaune', 'fuchsia', 'cyan', 'blanc'
    )
